package ch.epfl.tpp.sol.image;

import ch.epfl.tpp.sol.Color;
import ch.epfl.tpp.sol.Point;

public final class VerticalCompositeImage extends AbstractImage {
    private final Image top, bottom;
    private final double width, height;
    private final Color defaultColor;

    public VerticalCompositeImage(Image top, Image bottom, Color defaultColor) {
        this.top = top;
        this.bottom = bottom;
        this.width = Math.max(top.width(), bottom.width());
        this.height = top.height() + bottom.height();
        this.defaultColor = defaultColor;
    }
    
    @Override
    public double width() {
        return width;
    }

    @Override
    public double height() {
        return height;
    }

    @Override
    public Color colorAtPoint(Point p) {
        checkContainedPoint(p);
        if (bottom.containsPoint(p))
            return bottom.colorAtPoint(p);
        else {
            Point pT = p.translated(0, -bottom.height());
            return top.containsPoint(pT) ? top.colorAtPoint(pT) : defaultColor;
        }
    }
}
